Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2137)

Unified Diff: net/http/http_server_properties_impl.h

Issue 1858093002: Alt-Svc 8: Change Supports SPDY list using SHP as the key. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@alt_svc_7
Patch Set: server pref changes Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/http/http_server_properties.h ('k') | net/http/http_server_properties_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/http_server_properties_impl.h
diff --git a/net/http/http_server_properties_impl.h b/net/http/http_server_properties_impl.h
index 75a82c221f3971c1aadbee39b0b77780be11a5ca..2b15ea3d07cb2741b9585865a32df7cb627a8d52 100644
--- a/net/http/http_server_properties_impl.h
+++ b/net/http/http_server_properties_impl.h
@@ -80,8 +80,9 @@ class NET_EXPORT HttpServerPropertiesImpl
base::WeakPtr<HttpServerProperties> GetWeakPtr() override;
void Clear() override;
bool SupportsRequestPriority(const url::SchemeHostPort& server) override;
- bool GetSupportsSpdy(const HostPortPair& server) override;
- void SetSupportsSpdy(const HostPortPair& server, bool support_spdy) override;
+ bool GetSupportsSpdy(const url::SchemeHostPort& server) override;
+ void SetSupportsSpdy(const url::SchemeHostPort& server,
+ bool support_spdy) override;
bool RequiresHTTP11(const HostPortPair& server) override;
void SetHTTP11Required(const HostPortPair& server) override;
void MaybeForceHTTP11(const HostPortPair& server,
@@ -108,20 +109,20 @@ class NET_EXPORT HttpServerPropertiesImpl
const AlternativeServiceMap& alternative_service_map() const override;
scoped_ptr<base::Value> GetAlternativeServiceInfoAsValue() const override;
const SettingsMap& GetSpdySettings(
- const HostPortPair& host_port_pair) override;
- bool SetSpdySetting(const HostPortPair& host_port_pair,
+ const url::SchemeHostPort& origin) override;
+ bool SetSpdySetting(const url::SchemeHostPort& origin,
SpdySettingsIds id,
SpdySettingsFlags flags,
uint32_t value) override;
- void ClearSpdySettings(const HostPortPair& host_port_pair) override;
+ void ClearSpdySettings(const url::SchemeHostPort& origin) override;
void ClearAllSpdySettings() override;
const SpdySettingsMap& spdy_settings_map() const override;
bool GetSupportsQuic(IPAddress* last_address) const override;
void SetSupportsQuic(bool used_quic, const IPAddress& address) override;
- void SetServerNetworkStats(const HostPortPair& host_port_pair,
+ void SetServerNetworkStats(const url::SchemeHostPort& origin,
ServerNetworkStats stats) override;
const ServerNetworkStats* GetServerNetworkStats(
- const HostPortPair& host_port_pair) override;
+ const url::SchemeHostPort& origin) override;
const ServerNetworkStatsMap& server_network_stats_map() const override;
bool SetQuicServerInfo(const QuicServerId& server_id,
const std::string& server_info) override;
@@ -134,8 +135,8 @@ class NET_EXPORT HttpServerPropertiesImpl
private:
friend class HttpServerPropertiesImplPeer;
// |spdy_servers_map_| has flattened representation of servers (host, port)
// that either support or not support SPDY protocol.
typedef base::MRUCache<std::string, bool> SpdyServerHostPortMap;
typedef std::map<url::SchemeHostPort, url::SchemeHostPort> CanonicalHostMap;
typedef std::vector<std::string> CanonicalSufficList;
@@ -134,8 +135,8 @@ class NET_EXPORT HttpServerPropertiesImpl
private:
friend class HttpServerPropertiesImplPeer;
- // |spdy_servers_map_| has flattened representation of servers (host, port)
- // that either support or not support SPDY protocol.
+ // |spdy_servers_map_| has flattened representation of servers
+ // (scheme, host, port) that either support or not support SPDY protocol.
typedef base::MRUCache<std::string, bool> SpdyServerHostPortMap;
typedef std::map<url::SchemeHostPort, url::SchemeHostPort> CanonicalHostMap;
« no previous file with comments | « net/http/http_server_properties.h ('k') | net/http/http_server_properties_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698